package passbaseplugin.pettersonapps.com.passbase_flutter

import android.graphics.Color
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import com.passbase.passbase_sdk.Passbase

class PassbaseFlutterPlugin(passbase: Passbase): MethodCallHandler {
  private val passbaseRef: Passbase = passbase
  
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "passbase_flutter")
      channel.setMethodCallHandler(PassbaseFlutterPlugin(Passbase(registrar.activity())))
    }
  }

  override fun onMethodCall(call: MethodCall, result: Result) {
    when (call.method) {
      "initialize" -> {
        val arguments = InitializeArguments(call.arguments)
        passbaseRef.initialize(arguments.apiKey,
                arguments.prefillUserEmail,
                arguments.additionalArguments)

        result.success(null)
      }
      "startVerification" -> {
        passbaseRef.onCompletePassbaseVerification {
          result.success(it)
        }
        passbaseRef.onCancelPassbaseVerification {
          result.error("CANCEL", "Verification canceled", null)
        }
        passbaseRef.startVerification()
      }
      "setLoadingIndicatorColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setLoadingIndicatorColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setActionButtonBgColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setActionButtonBgColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setActionButtonDeactivatedBgColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setActionButtonDeactivatedBgColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setActionButtonTextColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setActionButtonTextColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setDisclaimerTextColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setDisclaimerTextColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setTitleTextColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setTitleTextColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      "setSubtitleTextColor" -> {
        val arguments = call.arguments as? ArrayList<Int>
        if (arguments == null || arguments.count() < 4) {
          result.error("ERROR", "Can't parse color", null)
        }
        val r = arguments!![0]
        val g = arguments!![1]
        val b = arguments!![2]
        val a = arguments!![3]

        passbaseRef.setSubtitleTextColor(Color.argb(a, r, g, b))
        result.success(null)
      }
      else -> {
        result.notImplemented()
      }
    }
  }
}


