import 'dart:async';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

const MethodChannel _channel = const MethodChannel('passbase_flutter');

class PassbaseFlutter {
  static UICustomization buttonUI = UICustomization();

  static Future<void> initialize(
      {@required String apiKey,
      Map<String, String> additionalAttributes,
      String prefillUserEmail}) async {
    assert(apiKey != null, "API key cannot be null!");

    Map arguments = new Map();
    arguments["apiKey"] = apiKey;

    if (additionalAttributes != null) {
      arguments["additionalAttributes"] = additionalAttributes;
    }
    if (prefillUserEmail != null) {
      arguments["prefillUserEmail"] = prefillUserEmail;
    }

    await _channel.invokeMethod('initialize', arguments);
    return;
  }

  static Future<void> startVerification({
    Function(String) onVerificationSuccess,
    Function onVerificationCancel,
  }) async {
    try {
      final String result = await _channel.invokeMethod('startVerification');
      onVerificationSuccess(result);
    } on PlatformException catch (error) {
      if (error.code == "CANCEL") {
        onVerificationCancel();
      }
    }
  }
}

class PassbaseButton extends StatelessWidget {
  final double width;
  final double height;
  final Color backgroundColor;
  final Function(String) onVerificationSuccess;
  final Function onVerificationCancel;

  PassbaseButton(
      {this.width,
      this.height,
      this.backgroundColor,
      this.onVerificationSuccess,
      this.onVerificationCancel});

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        borderRadius: BorderRadius.circular(5),
        color: this.backgroundColor ?? Colors.white,
        border: Border.all(color: Color(0xFFD5D5D5), width: 1),
      ),
      child: Material(
        color: Colors.transparent,
        child: InkWell(
          onTap: () async {
            await PassbaseFlutter.startVerification(
                onVerificationSuccess: onVerificationSuccess,
                onVerificationCancel: onVerificationCancel);
          },
          child: Container(
            width: width ?? 256,
            height: height ?? 55,
            child: Row(
              mainAxisSize: MainAxisSize.min,
              children: <Widget>[
                SizedBox(
                  width: 16,
                ),
                Image.asset(
                  "packages/passbase_flutter/assets/images/passbase-logo-icon.png",
                  width: 40,
                  height: 40,
                ),
                SizedBox(
                  width: 16,
                ),
                Padding(
                  padding: const EdgeInsets.only(top: 8, bottom: 8),
                  child: Container(
                    width: 1,
                    color: Color(0xFFD5D5D5),
                  ),
                ),
                SizedBox(
                  width: 16,
                ),
                Expanded(
                  child: Text(
                    "Verify me",
                    textAlign: TextAlign.center,
                    maxLines: 1,
                    overflow: TextOverflow.ellipsis,
                    style: TextStyle(fontSize: 17, fontWeight: FontWeight.bold),
                  ),
                ),
                SizedBox(
                  width: 16,
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

class UICustomization {
  Future<void> setActionButtonBgColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setActionButtonBgColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setActionButtonDeactivatedBgColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setActionButtonDeactivatedBgColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setActionButtonTextColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setActionButtonTextColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setDisclaimerTextColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setDisclaimerTextColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setTitleTextColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod(
        'setTitleTextColor', [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setSubtitleTextColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setSubtitleTextColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }

  Future<void> setLoadingIndicatorColor({Color color}) async {
    assert(color != null, "Color can't be null");
    await _channel.invokeMethod('setLoadingIndicatorColor',
        [color.red, color.green, color.blue, color.alpha]);
    return;
  }
}
